summaryrefslogtreecommitdiffstats
path: root/include/connection.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'include/connection.hpp')
-rw-r--r--include/connection.hpp11
1 files changed, 8 insertions, 3 deletions
diff --git a/include/connection.hpp b/include/connection.hpp
index 90027fb..fcb2a23 100644
--- a/include/connection.hpp
+++ b/include/connection.hpp
@@ -33,7 +33,12 @@ using std::string;
using std::string_view;
using std::variant;
-using endpoint_variant = variant<API::endpoint_type,string>;
+/*!
+ * @brief An endpoint. Either API::endpoint_type or `std::string_view`.
+ *
+ * @since 0.1.0
+ */
+using endpoint_variant = variant<API::endpoint_type,string_view>;
/*!
* @brief Represents a connection to an instance. Used for requests.
@@ -66,7 +71,7 @@ public:
* })};
* @endcode
*
* @param endpoint Endpoint as API::endpoint_type or `std::string`.
* @param parameters A map of parameters.
*
*
@@ -83,7 +88,7 @@ public:
* auto answer{connection.get("/api/v1/instance")};
* @endcode
*
* @param endpoint Endpoint as API::endpoint_type or `std::string`.
*
* @since 0.1.0
*/
@@ -66,7 +71,7 @@ public:
* @endcode
*
- * @param endpoint Endpoint as API::endpoint_type or `std::string`.
+ * @param endpoint Endpoint as API::endpoint_type or `std::string_view`.
* @param parameters A map of parameters.
*
@@ -83,7 +88,7 @@ public:
* @endcode
*
- * @param endpoint Endpoint as API::endpoint_type or `std::string`.
+ * @param endpoint Endpoint as API::endpoint_type or `std::string_view`.
*
* @since 0.1.0